# Code by KBK (?) From http://mini.net/tcl/949.html

#------------------------------------------------------------------
#
# printcanvas.tcl --
#
#   Tcl procedure to spool a canvas via PrFile32.
#
#------------------------------------------------------------------

package provide printcanvas 1.0
global DLL_DIR
namespace eval printcanvas {
    
    namespace export printcanvas
    
    # CONFIGURATION -- Path name of the PrintFile program.
    
    variable prfile "$DLL_DIR/Pfile/prfile32.exe"
    
}

#------------------------------------------------------------------
#
# printcanvas::printcanvas --
#
#   Print the contents of a canvas
#
# Parameters:
#   w -- Path name of the canvas
#
# Results:
#   None.
#
# Side effects:
#   Canvas content is converted to PostScript and spooled via
#   PrintFile.  If the canvas is larger than a printer page,
#   a file is created and spooled for each page.
#
#------------------------------------------------------------------

proc printcanvas::printcanvas { w } {
    
    variable prfile
    
    set name [file join $::env(TEMP) [pid]page]
    set cmd [list exec $prfile /q /delete]
    set i 0
    foreach { xmin ymin xmax ymax } [$w cget -scrollregion] {}
    for { set x $xmin } { $x < $xmax } { incr x 1200 } {
	for { set y $ymin } { $y < $ymax } { incr y 825 } {
	    set fname $name[incr i].ps
	    $w create text [expr { $x+1210 }] [expr { $y+835 }] \
                    -text "Page $i" -anchor nw \
                    -tags printCanvasPageNo \
                    -font {Helvetica -18}
	    eval [list $w create rectangle] \
                    [$w bbox printCanvasPageNo] \
                    [list -fill white -outline {} \
		    -tags printCanvasPageNoBg]
	    $w raise printCanvasPageNo printCanvasPageNoBg
	    $w postscript \
                    -file $fname \
                    -colormode gray \
                    -x $x -y $y -width 1350 -height 975 \
                    -pageheight 6.5i -pagewidth 9.0i \
                    -rotate true
	    lappend cmd $fname
	    $w delete printCanvasPageNo
	    $w delete printCanvasPageNoBg
	}
    }
    eval $cmd
    
    return
}

